@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef NOTIFICATIONSMODEL_H
@@ -26,7 +26,7 @@
 #include <QPixmap>
 #include <QList>
 
-#include "interfaces/dbusinterfaces.h"
+#include "dbusinterfaces.h"
 
 class KDECONNECTINTERFACES_EXPORT NotificationsModel
     : public QAbstractListModel
