@@ -29,7 +29,7 @@
 #include <core/device.h>
 #include <core/kdeconnectplugin.h>
 
-Q_LOGGING_CATEGORY(KDECONNECT_CONVERSATIONS, "kdeconnect.conversations")
+#include "kdeconnect_conversations_debug.h"
 
 QMap<QString, ConversationsDbusInterface*> ConversationsDbusInterface::liveConversationInterfaces;
 
@@ -190,23 +190,19 @@ void ConversationsDbusInterface::replyToConversation(const qint64& conversationI
 {
     const auto messagesList = m_conversations[conversationID];
     if (messagesList.isEmpty()) {
-        // Since there are no messages in the conversation, we can't do anything sensible
         qCWarning(KDECONNECT_CONVERSATIONS) << "Got a conversationID for a conversation with no messages!";
         return;
     }
 
-    if (messagesList.first().isMultitarget()) {
-        qWarning(KDECONNECT_CONVERSATIONS) << "Tried to reply to a group MMS which is not supported in this version of KDE Connect";
-        return;
-    }
+    const QList<ConversationAddress>& addressList = messagesList.first().addresses();
+    QVariant addresses;
+    addresses.setValue(addressList);
 
-    const QList<ConversationAddress>& addresses = messagesList.first().addresses();
-    if (addresses.size() > 1) {
-        // TODO: Upgrade for multitarget replies
-        qCWarning(KDECONNECT_CONVERSATIONS) << "Sending replies to multiple recipients is not supported";
-        return;
-    }
-    m_smsInterface.sendSms(addresses[0].address(), message);
+    m_smsInterface.sendSms(QDBusVariant(addresses), message, messagesList.first().subID());
+}
+
+void ConversationsDbusInterface::sendWithoutConversation(const QDBusVariant& addresses, const QString& message) {
+    m_smsInterface.sendSms(addresses, message);
 }
 
 void ConversationsDbusInterface::requestAllConversationThreads()
