@@ -20,6 +20,7 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QStyle>
 
 #include <KCMultiDialog>
 #include <KAboutData>
@@ -30,6 +31,7 @@
 int main(int argc, char** argv)
 {
     QApplication app(argc, argv);
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
     KAboutData about(QStringLiteral("kdeconnect-settings"),
                      i18n("KDE Connect Settings"),
                      QStringLiteral(KDECONNECT_VERSION_STRING),
@@ -49,6 +51,13 @@ int main(int argc, char** argv)
 
     KCMultiDialog* dialog = new KCMultiDialog;
     dialog->addModule(QStringLiteral("kcm_kdeconnect"), {parser.value(QStringLiteral("args"))});
+
+    auto style = dialog->style();
+    dialog->setContentsMargins(style->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                               style->pixelMetric(QStyle::PM_LayoutTopMargin),
+                               style->pixelMetric(QStyle::PM_LayoutRightMargin),
+                               style->pixelMetric(QStyle::PM_LayoutBottomMargin));
+
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->show();
 
